@@ -1,5 +1,5 @@
 from data_scraper import *
-def run_pypi_scraper(link):
-    Id="SOY3BJIM9Y3LDN6"
+def run_google_scraper(link):
+    Id="VKDU2XN03IQ3VD7"
     response=scraper.run(link,id=Id)
     return response
\ No newline at end of file
